//====================
//zepto.js 支持nexAll()
//====================
(function($){
	var e = {
	    nextAll: function(s) {
	        var $els = $(), $el = this.next()
	        while( $el.length ) {
	            if(typeof s === 'undefined' || $el.is(s)) $els = $els.add($el)
	            $el = $el.next()
	        }
	        return $els
	    }
	}
	$.extend( $.fn, e );
})(Zepto);


/**
 * 搜索栏推荐关键字（友好提示）功能
 * 因为用到回调函数，所以调用时要放在全局作用域
 * Author: Kiwi
 * Update: 2014-03-12
**/
var KeywordSuggestion = function(url, id_sug, id_text) {
	this.initialize(url, id_sug, id_text);
};
KeywordSuggestion.prototype = { //prototype可以理解成原型克隆对象
	initialize : function(url, id_sug, id_text) {
		this.url = url; //AJAX路径
		this.idSug = id_sug; //推荐关键字容器ID
		this.idText = id_text; //搜索栏ID
		
		this.currentSelIndex = -1; //当前推荐关键字位置，用于移动上下键时的事件
		this.oldSelIndex = -1; //旧推荐关键字位置，用于移动上下键时的事件
		this.searchtimeoutId = null; //timeout句柄
		
		//绑定键盘事件
		var bind_name = 'input';
		if (navigator.userAgent.indexOf("MSIE") != -1){//判定浏览器是否为IE浏览器
			bind_name = 'propertychange';
		}
		Zepto(this.idText).bind(bind_name, $.proxy(function(event) {
			$.proxy(this.selectItem(event), this);
		}, this));
		
		//点击this.idText以外的其他地方，this.idSug隐藏
		Zepto.prototype.isChildAndSelfOf = function(b) {
			return (this.closest(b).length > 0);
		};
		Zepto(document).click(Zepto.proxy(function(event) {
			//isChildAndSelfOf在IE里有未知BUG，改写
			if (! Zepto(event.target).closest(this.idText).length > 0) {
				Zepto(this.idSug).hide();
				
				//显示搜索框清空按钮
				$("#J_SearchClear").css("display", "none");
				$(".search-scan").css("width", "17px");
			}
		}, this));
	},
	
	//键盘事件
	selectItem : function(event) {
		var keyword = Zepto(this.idText).val();
		if (keyword == "") {
			Zepto(this.idSug).css("display", "none");
			return;
		} else {
			var li_length = Zepto(this.idSug).find("li").length; //获取列表数量
			//event.keyCode无法监控 未完成
			if (Zepto(this.idSug).css("display") != "none") {
				//上移或下移
				if (li_length > 0) {
					this.oldSelIndex = this.currentSelIndex;	
					if (this.currentSelIndex != -1) {
						var current_li = Zepto(this.idSug + " .j_Li-" + this.currentSelIndex).eq(0);
						current_li.css("backgroundColor", "#EEE");
						Zepto(this.idText).val(current_li.text());
					}
					if (this.oldSelIndex != -1) {
						var old_li = Zepto(this.idSug + " .j_Li-" + this.oldSelIndex).eq(0);
						old_li.css("backgroundColor", "#FFF");
					}
				}
			} else {
				//输入其他字符时去读数据，设置延时可以避免连续打字时读取太频繁
				clearTimeout(this.searchtimeoutId);
				this.searchtimeoutId = setTimeout(
					Zepto.proxy(function() {
						this.process(keyword);
					}, this), 500 
				);
				//this.currentSelIndex = -1;
				//this.oldSelIndex = -1;
			}
		}
	},
	
	//开始读数据
	process : function(keyword) {
		if (keyword != '') {
			//显示搜索框清空按钮
			$("#J_SearchClear").css("display", "inline-block");
			$(".search-scan").css("width", "0");
			
			Zepto(this.idSug).html("");
			this.getData(keyword);
			return;
		}
		Zepto(this.idSug).hide();
		
	},
	
	//ajax获取数据
	getData : function(text) {
		this.text = text;
		var data = 'text='+ encodeURIComponent(this.text);
		var url = this.url + '?' + data;
		Zepto.getJSON(url, Zepto.proxy(this.setData, this));
	},
	
	//ajax回调函数
	setData : function(tags) {
		if (tags) {
			var id_sug = this.idSug;
			var id_text = this.idText;
			
			var key_work = Zepto(id_text).val();
			var e_key = '<div class="searchPage-SubTextName"><span></span>搜索 "'+ key_work +'" 商品</div>';
			var e_ul = Zepto("<ul></ul>");
			Zepto(tags).each(function(id, tag) {
				var e_li = Zepto("<li></li>");
				e_li.attr("class", "j_Li-" + id);
				e_li.bind("click", function() {
					var keyword = Zepto(this).text();
					if (keyword == "") {
						Zepto(id_sug).hide();
						return;
					}
					Zepto(id_text).val(keyword);
					Zepto(id_sug).hide();
				});
				var e_div = Zepto("<div></div>").text(tag.name);//注意这里转换了特殊字符
				e_li.append(e_div);
				e_ul.append(e_li);
			});
			if (tags.length > 0) {			
				Zepto(this.idSug).append(e_key);
				Zepto(this.idSug).append(e_ul);
				e_ul.append('<li class="searchPage-subClose"><a id="J_CloseKeywordSug" href="javascript:void(0);">关闭</a></li>');
				Zepto(this.idSug).show();
			}
			
		} else {
			Zepto(this.idSug).hide();
			Zepto(this.idSug).html("");
		}
	}
};
